#!/bin/bash
#-------------------------------- Getting the Version Data -------------------------

# Get PROD JSON With GET Request
prod_json="$(curl https://storage.googleapis.com/app-releases-production/plugin_vscode/production/latest-single.json -H "Accept: application/json")"

# Get First PROD JSON Object in an array, and get the "tag" value
prod=$(echo "$prod_json" | jq '.tag' | tr -d '"')

# Get STAGING JSON With GET Request
staging_json="$(curl https://storage.googleapis.com/app-releases-staging/plugin_vscode/staging/latest-single.json -H "Accept: application/json")"

# Get First JSON Object in an array, and get the "tag" value
staging_tag=$(echo "$staging_json" | jq '.tag' | tr -d '"')

# Remove "-staging" from tag to manipulate numbers
staging=${staging_tag//"-staging"/}

#---------------------------------------------------------------------------

#------------------------------- Internal Version Extraction ---------------------

internal_version=$(jq -r .version package.json | cut -d'=' -f2)

#---------------------------------------------------------------------------------

#------------------------------- Staging Versioning Logic ------------------------

# Get the highest version number
highest_version=$(echo -e "$staging\n$prod\n$internal_version" | sort -V | tail -n 1)

if [ "$highest_version" != "$gradle" ]; then
  # Increment the patch version number by one
  next_version="${highest_version%.*}.$((${highest_version##*.} + 1))"
else
  # If gradle is the highest version, set next_version to gradle
  next_version="$gradle"
fi

# Output the next version number
echo $next_version-staging
